# Streamlit - Antv charts

A streamlit component to implement antv charts

## Installation

```
pip install streamlit-antv
```

## Usage

Refer to the following files for example usage
- [g6](g6/__init__.py)
- [g2](g2/__init__.py)
- [g2plot](g2plot/__init__.py)
